import llm
from transformers import AutoModel

MAX_LENGTH = 8192


@llm.hookimpl
def register_embedding_models(register):
    pass
    for model_id in (
        "hazo",
    ):
        register(HazoEmbeddingModel(model_id))


class HazoEmbeddingModel(llm.EmbeddingModel):
    def __init__(self, model_id):
        self.model_id = model_id
        self._model = None
        self.embedded_content = []

    def embed_batch(self, texts):
        if not hasattr(self, "batch_count"):
            self.batch_count = 0
        self.batch_count += 1
        for text in texts:
            self.embedded_content.append(text)
            words = text.split()[:16]
            embedding = [len(word) * 1.0 for word in words]
            # Pad with 0 up to 16 words
            embedding += [0.0] * (16 - len(embedding))
            yield embedding



from click.testing import CliRunner
from llm.cli import cli
import llm


def test_embed_hazo():
    model = llm.get_embedding_model("hazo")
    floats = model.embed("hello world")
    assert len(floats) == 16
    assert all(isinstance(f, float) for f in floats)
    assert floats ==  [5.0, 5.0] + [0.0] * 14

def test_hazo_embed_multi(tmpdir):
    db_path = str(tmpdir / "test.db")
    runner = CliRunner()
    result = runner.invoke(
        cli,
        [
            "embed-multi",
            "-m",
            "hazo",
            "test",
            "-",
            "-d",
            db_path,
        ],
        input='[{"id": "a", "text": "abc"}]',
        catch_exceptions=False,
    )
    assert result.exit_code == 0
